#!/bin/sh
#==============================================================================
# Component Name: Monitoring for WebSphere Application Server
# File Name:      itmwas_uninstall_prod.sh
#
# @(#)Description:    Uninstall the product.
#
# (C) COPYRIGHT Tivoli Systems, Inc. 2003
# Unpublished Work
# All Rights Reserved
# Licensed Material - Property of Tivoli Systems, Inc.
#
# 111719 - new 5.2 version
# 115590 6/08/03 mbk  Add rolling logs support
# 115653 6/12/03 mbk  Use "set -x" even when using ITMCSUtils (rolling logs)
# 116397 6/24/03 mww  Remove the right tag files for upgrade
# 120511 9/15/03 mww  Do not translate task library names.
# 120799 9/23/03 mww  Handle Interconnected TMRs.
# 121033 9/25/03 mww  Handle object and task Interconnected TMRs.
# 126081 1/07/04 mbk  Remove patch tag for 5.1.2 FPs
# $D1 140173 9/10/04 taf  Remove the tag files in DBDIR
# $F1 148461 5/23/05 mjk patch naming convention changed earlier in 05
#==============================================================================

rmtags()
{
	set -x
	set +e

	find "$BINDIR/../.." -name "ITMWAS*" -exec rm {} \;
	find "$BINDIR/../.." -name "pa_*-WAS-*" -exec rm {} \;
	find "$BINDIR/../.." -name "pa_*ITMWAS_*" -exec rm {} \;
	# @D1R
        # @D1A
        find "$DBDIR/.installed" -name "ITMWAS*" -exec rm {} \;
	find "$DBDIR/.installed" -name "pa_*-WAS-*" -exec rm {} \;
	find "$DBDIR/.installed" -name "pa_*ITMWAS_*" -exec rm {} \;
        # end @D1A
        
        # @F2A
	find "$BINDIR/../.." -name "pa_*TIV-ITM_WAS-*" -exec rm {} \;
	find "$DBDIR/.installed" -name "pa_*TIV-ITM_WAS-*" -exec rm {} \;

	# remove language pack tags

	for prod in $NLS_PRODS
	do
		if [ -f "$BINDIR"/../../msg_cat/.installed/"$prod"_CAT ]; then
			rm "$BINDIR"/../../msg_cat/.installed/"$prod"_CAT
		fi

		if [ -f "$BINDIR"/../lcf_bundle.40/.installed/"$prod"_LCFNEW ]; then
			rm "$BINDIR"/../lcf_bundle.40/.installed/"$prod"_LCFNEW
		fi

		if [ -f "$BINDIR"/../generic_unix/.installed/"$prod"_GBIN ]; then
			rm "$BINDIR"/../generic_unix/.installed/"$prod"_GBIN
		fi
	done

}

rmfiles()
{
	set -x
	set +e
 
	rm -rf $BINDIR/TME/WSAPPSVR 
	rm -rf $BINDIR/../generic_unix/TME/WSAPPSVR

	cd  "$BINDIR"/../lcf_bundle.40/bin
	find . -name WSAPPSVR* | xargs rm -rf

	cd  "$BINDIR"/../lcf_bundle.40/msg_cat/C
	rm -f WASPAC*.cat
	rm -f WebSphere*.cat
	rm -f AboutITMWASCatalog.cat
	rm -f itmwas*.cat

	rm -f "$DBDIR"/IZY/logs/config
	rm -f "$DBDIR"/IZY/logs/ffdc
	rm -f "$DBDIR"/IZY/logs/product
      
	cd "$BINDIR"/../..

	msgpath=`echo $NLSPATH | awk -F"%" '{print $1}'`
	cd  "$msgpath"

	find . -name WASPAC*.cat | xargs rm -f
	find . -name WebSphere*.cat | xargs rm -f
	find . -name itmwas*.cat | xargs rm -f
	find . -name AboutITMWASCatalog.cat | xargs rm -f

	# remove Language pack About catalog files and RM classes
	for prod in $NLS_PRODS
	do
   		find . -name About"$prod"Catalog.cat | xargs rm -f 2>/dev/null
	done
	rm -fr $BINDIR/../generic_unix/TME/IZY 2>/dev/null

	# Remove specific files
	cd $BINDIR/bin
	rm -f wwebsphere* wwaspacattr* wwaspacdispconf* wwaspacdispout*
}

# Remove language pack product info
rmnls()
{
	set -x

	for prod in $NLS_PRODS
	do
		if wlookup -r ProductInfo -o "$prod" > /dev/null 2>&1
	then
		wdel @ProductInfo:"$prod"
	fi
	done

}

# remove TMR roles and Resource roles
remove_role()
{
	set -x
	set +e

	admin_coll=`wlookup Administrators`

	# remove roles from administrators
	Admins=`wls -l /Library/Administrator | awk '{print $1}'`
	for i in $Admins
	do
		alias=`idlcall $i get_aliases | idlarg 2 | awk -F\" '{print $2}'`
		groups=`objcall $TMR.0.0 get_principal_roles $alias 2>/dev/null | grep $1`
		for j in $groups
		do
			secgroup=`echo $j | sed 's/:/ /g'`
			cnt=1
			for k in $secgroup
			do
				if [ $cnt -eq 1 ]; then
					newgrp=$k
					cnt=`expr $cnt + 1 `
				else
					if [ "$k" != "$1" ]; then
						newgrp="$newgrp $k"
					fi
				fi
			done
			objcall $TMR.0.0 set_principal_roles $alias $newgrp
		done
	done

	# Remove TMR roles and Resource roles
	# If the roles have already been removed, you will get marshalling 
	# errors ; so check first to see if the wasav roles exist  
	# You must restart the console to see the result of the
	# remove on the desktop.
	#   

	ROLES=`idlcall $admin_coll _get_supported_roles`
	echo $ROLES | grep $1 > /dev/null

	# If wasav is in the roles continue
	if [ $? -eq 0 ] ; then

		COUNT=`echo $ROLES | idlarg 1`
		COUNT1=`expr $COUNT - 1`
		TMR_ROLES=`idlcall $admin_coll _get_supported_tmr_roles`
		echo $TMR_ROLES | grep $1  > /dev/null

		# If wasav is in the roles continue
		if [ $? -eq 0 ] ; then

			TCOUNT=`echo $TMR_ROLES | idlarg 1`
			TCOUNT1=`expr $TCOUNT - 1`
			ROLES1=`echo $ROLES | sed 's/'"\"$1\""'//g'`
			TMR_ROLES1=`echo $TMR_ROLES | sed 's/'"\"$1\""'//g'`
			ROLES=`echo $ROLES1 | sed 's/'"$COUNT"'/'"$COUNT1"'/g'`
			TMR_ROLES=`echo $TMR_ROLES1 | sed 's/'"$TCOUNT"'/'"$TCOUNT1"'/g'`
			idlcall $admin_coll _set_supported_roles $ROLES
			idlcall $admin_coll _set_supported_tmr_roles $TMR_ROLES
		fi
	fi
}

##################################################################
### remove tasks in task librarys, then remove the librarys    ###
##################################################################
rm_tasks()
{
	set -x

	TLIB="$1"
	wlstlib "$TLIB#$IRONAME" >$TMP/tmp.$$

	while read type taskname
	do

		wdeltask "$taskname" "$TLIB#$IRONAME" 2>/dev/null
		wdeljob "$taskname" "$TLIB#$IRONAME" 2>/dev/null

	done < $TMP/tmp.$$

	# 120799 - Append IRONAME for Interconnected TMRs
	wdel @TaskLibrary:"$TLIB#$IRONAME"

}

RemoveObject()
{
	set -x

	if [ -n "$1" ]; then

		LABEL=`idlcall "$1" _get_label`
		idlcall -T top "$1" remove > /dev/null 2>&1

		if [ $? -ne 0 ]; then

			# Forcefully Removing $LABEL
			objcall "$1" _delete > /dev/null 2>&1

			if [ $? -ne 0 ]; then

				# Very Forcefully Removing $LABEL
				objcall "$1" o_rmob > /dev/null 2>&1

			fi
		fi
	fi
}

main_init()
{
	set -x

	# setup up some global variables
	OSERV=`objcall 0.0.0 get_oserv`
	export OSERV

	INTERP=`objcall $OSERV query interp`
	export INTERP

	REMOVEFILES="NO"

	INST_DIR=`objcall $OSERV query install_dir`
	export INST_DIR
	case "$INTERP" in

		w32-ix86) INSTDIR=`env | grep "INST_DIR" | awk -F= '{print $2}' | sed -e 's,\\\\,/,g'`;;

		*) INSTDIR=$INST_DIR;;

	esac

	BINDIR=$INSTDIR/$INTERP

	# Add location of wbindmsg to Path
	PATH="$BINDIR"/TME/WSAPPSVR/utils:$PATH
	export PATH

	DBDIR=`objcall $OSERV query db_dir`

	if [ $NUM_PARMS -gt 0 ] ; then

		parm1=`echo "$FIRST_PARM" | tr [a-z] [A-Z]`
		if [ $parm1 = "-RMFILES" ]; then

  			REMOVEFILES="YES"
		fi
	fi

	# Get the region name to avoid collisions

	IRO=`wlookup InterRegion`
	export IRO
	eval IRONAME=`idlattr -t -g $IRO name string`
	export IRONAME

	TOP_PR="Monitoring for WebSphere Application Server"
	export TOP_PR

	TMR=`objcall 0.0.0 get_oserv | awk -F. '{print $1}'`

	# here are the language pack product names
	NLS_PRODS="IZY_DE_5.1.0 \
                   IZY_ES_5.1.0 \
                   IZY_FR_5.1.0 \
                   IZY_IT_5.1.0 \
                   IZY_JA_5.1.0 \
                   IZY_KO_5.1.0 \
                   IZY_PTBR_5.1.0 \
                   IZY_ZHCN_5.1.0 \
                   IZY_ZHTW_5.1.0 \
                   IZY_DE_5.1.1 \
                   IZY_ES_5.1.1 \
                   IZY_FR_5.1.1 \
                   IZY_IT_5.1.1 \
                   IZY_JA_5.1.1 \
                   IZY_KO_5.1.1 \
                   IZY_PTBR_5.1.1 \
                   IZY_ZHCN_5.1.1 \
                   IZY_ZHTW_5.1.1 \
                   IZY_DE_5.1.2 \
                   IZY_ES_5.1.2 \
                   IZY_FR_5.1.2 \
                   IZY_IT_5.1.2 \
                   IZY_JA_5.1.2 \
                   IZY_KO_5.1.2 \
                   IZY_PTBR_5.1.2 \
                   IZY_ZHCN_5.1.2 \
                   IZY_ZHTW_5.1.2"

	# determine if TMR (if not, just remove files)

	DISP=`objcall 0.0.0 get_oserv | awk -F. '{print $2}'`

	if [ $DISP -ne 1 ]; then

		if [ $REMOVEFILES = "YES" ] ; then
			rmfiles
		fi 

		rmtags
		host=`uname -n | tr '[A-Z]' '[a-z]'`
		echo "Uninstall on $host complete"
		exit 0
	fi 
}

delete_resource_models()
{
	set -x

	RMLIST=`wdmrm -list | grep "^Resource" | grep WebSphere | grep -v WebSphere_MQ | awk '{print $3}'`

	for rm in $RMLIST
	do
  		RESULT=`wdmrm -remove $rm`
	done
}

delete_profile_managers()
{
	set -x

	OFS=$IFS
	PROFMGRS=`wls -l @PolicyRegion:"$TOP_PR#$IRONAME" | grep "ProfileManager" | awk -F# '{print $3}' | cut -f2 | awk -F+ '{printf("%s+",$1)}'`

	IFS=+

	for profilemgr in $PROFMGRS
	do

		# 120799 - Append the IRONAME for interconnect TMRs
		PROFILES=`wls -l @ProfileManager:"$profilemgr#$IRONAME" | awk -F# '{print $3}' | cut -f2 | awk -F+ '{printf("%s+", $1)}'`

		for prf in $PROFILES
		do

			type=`wls -l @ProfileManager:"$profilemgr#$IRONAME" | grep "$prf" | awk -F# '{print $2}' | awk -F: '{print $1}'`

			if [ "$type" = "TMW2K" ]; then

				RMS=`wdmeditprf -P "${prf}#$IRONAME" -list | grep WebSphere | grep -v WebSphere_MQ | awk '{print $1}' | awk -F+ '{printf("%s+",$1)}'`

				for rm in $RMS
				do

					# If resource models are deleted first,
					# then we may not have anything to 
					# remove here, but we'll check anyway

					wdmeditprf -P "${prf}#$IRONAME" -remove $rm
				done

				wdel "@Tmw2kProfile:$prf#$IRONAME"

			else
				wdel "@type:$prf#$IRONAME"
			fi
		done

		wdel @ProfileManager:"$profilemgr#$IRONAME"

	done

	IFS=$OFS
}

delete_deps()
{
	set -x

	# delete the dependencys, we don't delete the head node

	RESULT=`wdepset -e @DependencyMgr:itmwas_run_task_dep -r depset @DependencyMgr:itmwas_tool_dep 2>&1`
	WASAV_TOOL_DEP=`wlookup -r DependencyMgr itmwas_tool_dep 2>/dev/null`

	if [ x"$WASAV_TOOL_DEP" != x ] ; then

		RESULT=`wdepset -d @DependencyMgr:itmwas_tool_dep 2>&1`
	fi

	# remove the dependency that we associated with the 
	# various class init methods we established in itmwas_tool_dep.sh

	WASAV_OBJ_DEP=`wlookup -r DependencyMgr ITMWAS_dep 2>/dev/null`

	if [ x"$WASAV_OBJ_DEP" != x ] ; then

		RESULT=`wdepset -d @DependencyMgr:ITMWAS_dep 2>&1`
	fi

	# synchronize all gateways 
	for gw in `wlookup -L -r Gateway -a`
	do
		set +e
		wgateway $gw dbcheck
	done
}

delete_object()
{
	set -x

	OBJECT_CLASS="$1"
	PDO="$1PD"

	# lookup puts tab chars in output, hence the tr
	wlookup -r $1 -a -L | tr -d '\011' > $TMP/tmp.$$

	OLDIFS=$IFS

	# change to | cause they are not supported in label names
	IFS=\|

	while read WSLABEL
	do

		OBJ=`wlookup -or "$1" "$WSLABEL#$IRONAME" 2>/dev/null`
		RemoveObject "$OBJ"

	done < $TMP/tmp.$$

	IFS=$OLDIFS
	rm $TMP/tmp.$$

	OBJ=`wlookup -or "Presentation" "$1#$IRONAME"`
	RemoveObject "$OBJ"

	if [ "$PDO" != "WebSphereObjectPD" ] && [ "$PDO" != "IWebSphereObjectPD" ] ; then

		OBJ=`wlookup -or "Presentation" "$PDO#$IRONAME"`
		RemoveObject "$OBJ"

	fi

}

delete_objects()
{
	set -x

	delete_object WSApplicationServer
	delete_object WSAdministrationServer
	delete_object WebSphereObject
	delete_object IWSApplicationServer
	delete_object IWSNodeAgent
	delete_object IWSDeploymentManager
	delete_object IWebSphereObject

}

##################################################################
### TEC stuff, if not installed, will get "not found" msgs     ###
##################################################################
delete_tec()
{
	set -x
	set +e

	if [ -f "$BINDIR/bin/wlssrc.exe" ] || [ -f "$BINDIR/bin/wlssrc" ]; then

		ITMWAS_TEC=`wlssrc | grep "ITMWAS"`

		if [ x"$ITMWAS_TEC" != x ] ; then
			wdelsrc ITMWAS
		fi

		ITMWAS_TEC=`wlsrb | grep "ITMWAS"`

		if [ x"$ITMWAS_TEC" != x ] ; then
			wdelrb ITMWAS
		fi
	fi
}

delete_tasks()
{
	set -x
 
	rm_tasks "WebSphere Application Server Tasks"

	rm_tasks "WebSphere Administration Server Tasks"

	rm_tasks "WebSphere Event Tasks"

	rm_tasks "WebSphere Application Server Utility Tasks"

	rm_tasks "WebSphere Hidden Utility Tasks"

	rm_tasks "WebSphere Deployment Manager Server Tasks"

	rm_tasks "WebSphere Node Agent Server Tasks"

	# delete associated task files

	cd $BINDIR/../generic_unix/TAS/TASK_LIBRARY/bin
	find . -name WebSphere_App* | xargs rm
	find . -name WebSphere_Adm* | xargs rm
	find . -name WebSphere_Eve* | xargs rm
	find . -name itmwas_* | xargs rm

}

##################################################################
### remove classes, remove names from registry                 ###
##################################################################
delete_classes()
{
	set -x

	TNR=`wlookup NameRegistry`

	wregister -u -r Classes "WSApplicationServerPD" 
	wregister -u -r Classes "WSApplicationServer" 
	wregister -u -r Classes "WSAdministrationServerPD" 
	wregister -u -r Classes "WSAdministrationServer" 
	wregister -u -r Classes "WebSphereObject" 

	wregister -u -r Classes "IWSApplicationServerPD"
	wregister -u -r Classes "IWSApplicationServer"
	wregister -u -r Classes "IWSNodeAgentPD"
	wregister -u -r Classes "IWSNodeAgent"
	wregister -u -r Classes "IWSDeploymentManagerPD"
	wregister -u -r Classes "IWSDeploymentManager"
	wregister -u -r Classes "IWebSphereObject"

	idlcall $TNR remove '\"WSApplicationServerPD\" FALSE' 
	idlcall $TNR remove '\"WSApplicationServer\" FALSE' 
	idlcall $TNR remove '\"WSAdministrationServerPD\" FALSE' 
	idlcall $TNR remove '\"WSAdministrationServer\" FALSE' 
	idlcall $TNR remove '\"WebSphereObject\" FALSE' 

	idlcall $TNR remove '\"IWSApplicationServerPD\" FALSE' 
	idlcall $TNR remove '\"IWSApplicationServer\" FALSE' 
	idlcall $TNR remove '\"IWSNodeAgentPD\" FALSE' 
	idlcall $TNR remove '\"IWSNodeAgent\" FALSE' 
	idlcall $TNR remove '\"IWSDeploymentManagerPD\" FALSE' 
	idlcall $TNR remove '\"IWSDeploymentManager\" FALSE' 
	idlcall $TNR remove '\"IWebSphereObject\" FALSE' 

	wdel "/Library/WSApplicationServerPD" 
	wdel "/Library/WSApplicationServer" 
	wdel "/Library/WSAdministrationServerPD" 
	wdel "/Library/WSAdministrationServer" 
	wdel "/Library/WebSphereObject" 

	wdel "/Library/IWSApplicationServerPD" 
	wdel "/Library/IWSApplicationServer" 
	wdel "/Library/IWSNodeAgentPD" 
	wdel "/Library/IWSNodeAgent" 
	wdel "/Library/IWSDeploymentManagerPD" 
	wdel "/Library/IWSDeploymentManager" 
	wdel "/Library/IWebSphereObject" 

}

##################################################################
### remove roles, Police Region and run wchkdb   ###
##################################################################
delete_roles_and_PR()
{
	set -x

	remove_role websphereappsvr_user
	remove_role websphereappsvr_admin
	remove_role websphereappsvr_super

	wdel @PolicyRegion:"WebSphere Application Servers#$IRONAME"
	wdel @PolicyRegion:"Monitoring for WebSphere Application Server Internal#$IRONAME"

	# Remove any empty Policy Regions under the top region

	OFS=$IFS
	POLICYREGS=`wls -l @PolicyRegion:"Monitoring for WebSphere Application Server"#$IRONAME | grep "PolicyRegion"  | awk -F# '{print $3}' | cut -f2 | awk -F+ '{printf("%s+",$1)}'`
	IFS=+
	for policyreg in $POLICYREGS
	do

		wdel @PolicyRegion:"$policyreg"#$IRONAME

	done
	IFS=$OFS

	wdel @PolicyRegion:"$TOP_PR#$IRONAME"

	# unregister this script from Uninstall
	wregister -u -r Uninstall ITMWAS

	rmtags

	if [ $REMOVEFILES = "YES" ] ; then

		rmfiles
	fi

	# remove language pack product info
	rmnls

}

main ()
{

	TMP=`wtemp`  # Used by other functions

  	LOGDIR="$DBDIR/IZY/logs"
	if [ ! -d $LOGDIR ]; then
           mkdir -p $LOGDIR
	fi

        # 115590 6/8/03 mbk Use ITMCS rolling logs function if available
        # if not found, log the old way
        # need bindir (install dir) setup to find ITMCS install directory
        OSERV=`objcall 0.0.0 get_oserv`
        export OSERV

        INST_DIR=`objcall $OSERV query install_dir`
        export INST_DIR
        case "$INTERP" in
           w32-ix86) INSTDIR=`env | grep "INST_DIR" | awk -F= '{print $2}' | sed -e 's,\\\\,/,g'`;;
           *) INSTDIR=$INST_DIR;;
        esac

        BINDIR=$INSTDIR/$INTERP

	TASKNAME="itmwas_uninstall_prod"
	if [ -f "$BINDIR"/TME/APPLSVCS/ITMCSUtils.sh ] ; then
    	  . "$BINDIR"/TME/APPLSVCS/ITMCSUtils.sh
    	  ITMCS_rolling_log_init "IZY" "${TASKNAME}" ""
	else

	  LOGFILE=$LOGDIR/trace_itmwas_uninstall_prod.log

	  # setup trace
	  echo `wbindmsg itmwas_sh 4 "IZY1004I Log information is written to: %1\\\$s" "$LOGFILE"`
	  echo ""

	  # redirect stderr to the logfile
	  umask 002
	  rm "$LOGFILE" 2> /dev/null
	  exec 2> "$LOGFILE"

	  echo "*** Starts on `date`">&2

	  # dump environment variables

	  echo "==================================">&2
	  echo "= Environment Variables Start...">&2
	  echo "==================================">&2

	  ENVS=`set`
	  echo "$ENVS">&2
	  echo "">&2
	  echo "==================================">&2
	  echo "">&2

	  echo "==================================">&2
	  echo "= Main Code Start...">&2
	  echo "==================================">&2
	fi

	# 115653 6/12/03 mbk  Use "set -x" even when using ITMCSUtils (rolling logs)
	set -x

	set +e

	main_init

	delete_objects
	delete_resource_models
	delete_profile_managers
	delete_deps
	delete_tasks
	delete_tec
	delete_classes
	delete_roles_and_PR

	# Remove the product name
	wdel @ProductInfo:ITMWAS

	patches=`wlookup -ar PatchInfo | cut -f1 | grep "5.1.0-WAS"`
	for patch in $patches 
	do
		wdel @PatchInfo:"$patch"
	done

	patches=`wlookup -ar PatchInfo | cut -f1 | grep "ITMWAS_5"`
	for patch in $patches 
	do
		wdel @PatchInfo:"$patch"
	done

	# 126081 1/07/04 mbk  Remove patch tag for 5.1.2 FPs
	patches=`wlookup -ar PatchInfo | cut -f1 | grep "5.1.2-WAS"`
	for patch in $patches 
	do
		wdel @PatchInfo:"$patch"
	done
        
	#  @F2A mjk New patch naming convention Remove patch tag for 5.1.2 fixes
	patches=`wlookup -ar PatchInfo | cut -f1 | grep "5.1.2-TIV-ITM_WAS"`
	for patch in $patches 
	do
		wdel @PatchInfo:"$patch"
	done
        #  @F2A end
}

NUM_PARMS=$#
export NUM_PARMS
FIRST_PARM=$1
export FIRST_PARM
main 

exit 0
